@@ -31,6 +31,10 @@ AUTH_ACTIONS = [
 REQUEST_TIMEOUT = 30
 
 
+class ArchimedesCommandLineConfigReadException(Exception):
+    """Exception for config read errors."""
+
+
 def get_accepted_env():
     """Fetches allowed values of env keys."""
     for _ in range(0, 10):
@@ -42,7 +46,9 @@ def get_accepted_env():
             return tuple(response.keys())
         except:  # pylint:disable=bare-except
             sleep(3)
-    raise Exception("Unable to get config from arclconfig.")
+    raise ArchimedesCommandLineConfigReadException(
+        "Unable to get config from arclconfig."
+    )
 
 
 class ArchimedesAuth:
