@@ -20,7 +20,7 @@ from arcl.auth import (
 )
 from arcl.config import get_config_path
 
-CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])
+CONTEXT_SETTINGS = {"help_option_names": ["-h", "--help"]}
 COOKIECUTTER_TEMPLATE_GIT_URL = (
     "https://github.com/OptimeeringAS/archimedes-cookiecutter.git"
 )
@@ -40,6 +40,10 @@ class ConfigNotFoundException(Exception):
     """Exception to raise when config not in config path"""
 
 
+class PythonVersionException(Exception):
+    """Exception to raise when python version cannot be determined"""
+
+
 def get_author_name(user):
     """Returns the authors name"""
     name = user.get("name")
@@ -76,7 +80,7 @@ def get_python_version():
         "and `python` is available in path."
     )
     print(errors)
-    raise Exception("Error while trying to get available python version")
+    raise PythonVersionException("Error while trying to get available python version")
 
 
 def _get_version_from_python_version_string(version_string):
